==> nodejs_interop-0.7.0.tar.gz: lib/src/npm/del.dart <==
part of nodejs_interop.npm;

/// The [`del`](https://www.npmjs.com/package/del) module.
@JS()
abstract class DelModule implements Function {

  /// Deletes the file system entities corresponding to the specified globbing [patterns] for files.
  ///
  /// The file [patterns] can be a [String] or a [List] of strings.
  /// Returns a [Promise] that resolves with the paths of the deleted entities.
  external Promise<List<String>> call(patterns, [DeleteOptions options]);

  /// Synchronously deletes the file system entities corresponding to the specified globbing [patterns] for files.
  ///
  /// The file [patterns] can be a [String] or a [List] of strings.
  /// Returns the paths of the deleted entities.
  external List<String> sync(patterns, [DeleteOptions options]);
}

/// Options used to customize the file deletion.
@JS()
@anonymous
class DeleteOptions extends GlobOptions {

  /// Creates a new options object.
  external factory DeleteOptions({
    int concurrency,
    bool dryRun = false,
    bool force = false,
    cache,
    String cwd,
    bool dot = false,
    bool mark = false,
    bool nomount = false,
    bool nosort = false,
    bool nounique = false,
    String root,
    bool silent = false,
    bool stat = false,
    statCache,
    bool strict = false,
    symlinks
  });

  /// The maximum number of concurrent operations.
  external int get concurrency;
  external set concurrency(int value);

  /// Whether to only return the paths that would be deleted, without removing the corresponding file system entities.
  external bool get dryRun;
  external set dryRun(bool value);

  /// Whether to allow deleting the current working directory and outside.
  external bool get force;
  external set force(bool value);
}

/// Options used to customize the file globbing.
/// TODO: finish the implementation!
@JS()
@anonymous
class GlobOptions {

  /// Creates a new options object.
  external factory GlobOptions({
    cache,
    String cwd,
    bool dot = false,
    bool mark = false,
    bool nomount = false,
    bool nosort = false,
    bool nounique = false,
    String root,
    bool silent = false,
    bool stat = false,
    statCache,
    bool strict = false,
    symlinks
  });

  /// A previously generated cache object to save some `fs` calls.
  external dynamic get cache;
  external set cache(value);

  /// The current working directory in which to search. Defaults to `process.cwd()`.
  external String get cwd;
  external set cwd(String value);

  /// Include .dot files in normal matches and globstar matches.
  /// Note that an explicit dot in a portion of the pattern will always match dot files.
  external bool get dot;
  external set dot(bool value);

  /// Add a `/` character to directory matches. Note that this requires additional stat calls.
  external bool get mark;
  external set mark(bool value);

  /// By default, a pattern starting with a forward-slash will be "mounted" onto the root setting,
  /// so that a valid filesystem path is returned. Set this flag to disable that behavior.
  external bool get nomount;
  external set nomount(bool value);

  /// Don't sort the results.
  external bool get nosort;
  external set nosort(bool value);

  /// In some cases, brace-expanded patterns can result in the same file showing up multiple times in the result set.
  /// By default, this implementation prevents duplicates in the result set. Set this flag to disable that behavior.
  external bool get nounique;
  external set nounique(bool value);

  /// The place where patterns starting with `/` will be mounted onto. Defaults to `path.resolve(options.cwd, "/")`.
  external String get root;
  external set root(String value);

  /// When an unusual error is encountered when attempting to read a directory,
  /// a warning will be printed to `stderr`. Set this flag to suppress these warnings.
  external bool get silent;
  external set silent(bool value);

  /// Set this flag to stat all results.
  /// This reduces performance somewhat, and is completely unnecessary,
  /// unless `fs.readdir()` is presumed to be an untrustworthy indicator of file existence.
  external bool get stat;
  external set stat(bool value);

  /// A cache of results of filesystem information, to prevent unnecessary `fs.stat()` calls.
  external dynamic get statCache;
  external set statCache(value);

  /// When an unusual error is encountered when attempting to read a directory,
  /// the process will just continue on in search of other matches. Set this flag to raise an error in these cases.
  external bool get strict;
  external set strict(bool value);

  /// A cache of known symbolic links, to prevent unnecessary `fs.lstat()` calls.
  external dynamic get symlinks;
  external set symlinks(value);
}

==> nodejs_interop-0.8.0.tar.gz: lib/src/npm/del.dart <==
/// Support for interoperating with [`del`](https://www.npmjs.com/package/del) package.
@JS()
library nodejs_interop.npm.del;

import 'package:js/js.dart';
import 'package:nodejs_interop/js.dart';

/// The [`del`](https://www.npmjs.com/package/del) module.
@JS()
abstract class DelModule implements Function {

  /// Deletes the file system entities corresponding to the specified globbing [patterns] for files.
  ///
  /// The file [patterns] can be a [String] or a [List] of strings.
  /// Returns a [Promise] that resolves with the paths of the deleted entities.
  external Promise<List<String>> call(patterns, [DelOptions options]);

  /// Synchronously deletes the file system entities corresponding to the specified globbing [patterns] for files.
  ///
  /// The file [patterns] can be a [String] or a [List] of strings.
  /// Returns the paths of the deleted entities.
  external List<String> sync(patterns, [DelOptions options]);
}

/// Options used to customize the file deletion.
@JS()
@anonymous
class DelOptions extends GlobOptions {

  /// Creates a new options object.
  external factory DelOptions({
    int concurrency,
    bool dryRun = false,
    bool force = false,
    cache,
    String cwd,
    bool dot = false,
    bool mark = false,
    bool nomount = false,
    bool nosort = false,
    bool nounique = false,
    String root,
    bool silent = false,
    bool stat = false,
    statCache,
    bool strict = false,
    symlinks
  });

  /// The maximum number of concurrent operations.
  external int get concurrency;
  external set concurrency(int value);

  /// Whether to only return the paths that would be deleted, without removing the corresponding file system entities.
  external bool get dryRun;
  external set dryRun(bool value);

  /// Whether to allow deleting the current working directory and outside.
  external bool get force;
  external set force(bool value);
}

/// Options used to customize the file globbing.
/// TODO: finish the implementation!
@JS()
@anonymous
class GlobOptions {

  /// Creates a new options object.
  external factory GlobOptions({
    cache,
    String cwd,
    bool dot = false,
    bool mark = false,
    bool nomount = false,
    bool nosort = false,
    bool nounique = false,
    String root,
    bool silent = false,
    bool stat = false,
    statCache,
    bool strict = false,
    symlinks
  });

  /// A previously generated cache object to save some `fs` calls.
  external dynamic get cache;
  external set cache(value);

  /// The current working directory in which to search. Defaults to `process.cwd()`.
  external String get cwd;
  external set cwd(String value);

  /// Include .dot files in normal matches and globstar matches.
  /// Note that an explicit dot in a portion of the pattern will always match dot files.
  external bool get dot;
  external set dot(bool value);

  /// Add a `/` character to directory matches. Note that this requires additional stat calls.
  external bool get mark;
  external set mark(bool value);

  /// By default, a pattern starting with a forward-slash will be "mounted" onto the root setting,
  /// so that a valid filesystem path is returned. Set this flag to disable that behavior.
  external bool get nomount;
  external set nomount(bool value);

  /// Don't sort the results.
  external bool get nosort;
  external set nosort(bool value);

  /// In some cases, brace-expanded patterns can result in the same file showing up multiple times in the result set.
  /// By default, this implementation prevents duplicates in the result set. Set this flag to disable that behavior.
  external bool get nounique;
  external set nounique(bool value);

  /// The place where patterns starting with `/` will be mounted onto. Defaults to `path.resolve(options.cwd, "/")`.
  external String get root;
  external set root(String value);

  /// When an unusual error is encountered when attempting to read a directory,
  /// a warning will be printed to `stderr`. Set this flag to suppress these warnings.
  external bool get silent;
  external set silent(bool value);

  /// Set this flag to stat all results.
  /// This reduces performance somewhat, and is completely unnecessary,
  /// unless `fs.readdir()` is presumed to be an untrustworthy indicator of file existence.
  external bool get stat;
  external set stat(bool value);

  /// A cache of results of filesystem information, to prevent unnecessary `fs.stat()` calls.
  external dynamic get statCache;
  external set statCache(value);

  /// When an unusual error is encountered when attempting to read a directory,
  /// the process will just continue on in search of other matches. Set this flag to raise an error in these cases.
  external bool get strict;
  external set strict(bool value);

  /// A cache of known symbolic links, to prevent unnecessary `fs.lstat()` calls.
  external dynamic get symlinks;
  external set symlinks(value);
}
